summaryrefslogtreecommitdiff
path: root/internal
diff options
context:
space:
mode:
Diffstat (limited to 'internal')
-rw-r--r--internal/util/util_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/util/util_test.go b/internal/util/util_test.go
index be19b11..cb82123 100644
--- a/internal/util/util_test.go
+++ b/internal/util/util_test.go
@@ -15,8 +15,8 @@ func TestEnsureValidURL(t *testing.T) {
testCases := map[string]string{
// Make sure we set https
"example.com/": "https://example.com/",
- // Make sure we do not override the scheme if provided
- "http://example.com/": "http://example.com/",
+ // Make sure we do override the scheme to https
+ "http://example.com/": "https://example.com/",
// This URL is already valid
"https://example.com/": "https://example.com/",
// Make sure to add a trailing slash (/)